from setuptools import setup

setup(name='Gauss_dist',
      version='0.1',
      description='Gaussian and Binomial distributions',
      packages=['Gauss_dist'],
      author = 'Vardan Sharma',
      author_email = 'vardans6@gmail.com',
      zip_safe=False)
